summaryrefslogtreecommitdiff
path: root/src/waypoint_base.h
diff options
context:
space:
mode:
authortruebrain <truebrain@openttd.org>2011-12-20 17:57:56 +0000
committertruebrain <truebrain@openttd.org>2011-12-20 17:57:56 +0000
commit1c9bec19993417b1f3b240f2bdb0745aa26c0cb3 (patch)
treed09407cc962ee87ac1bbbbc60951cad74c6b1db7 /src/waypoint_base.h
parent7a38642a1c83531a65907ae784bc03a82d35132a (diff)
downloadopenttd-1c9bec19993417b1f3b240f2bdb0745aa26c0cb3.tar.xz
(svn r23640) -Fix: stop using FORCEINLINE (1/3rd of the instances were, the others were still regular inline), but make sure inline is always a 'forced' inline (I am looking at you MSVC)
Diffstat (limited to 'src/waypoint_base.h')
-rw-r--r--src/waypoint_base.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/waypoint_base.h b/src/waypoint_base.h
index 01c0ae173..c97c6089c 100644
--- a/src/waypoint_base.h
+++ b/src/waypoint_base.h
@@ -27,7 +27,7 @@ struct Waypoint FINAL : SpecializedStation<Waypoint, true> {
void UpdateVirtCoord();
/* virtual */ FORCEINLINE bool TileBelongsToRailStation(TileIndex tile) const
{
return IsRailWaypointTile(tile) && GetStationIndex(tile) == this->index;
}
@@ -50,7 +50,7 @@ struct Waypoint FINAL : SpecializedStation<Waypoint, true> {
* Is this a single tile waypoint?
* @return true if it is.
*/
- FORCEINLINE bool IsSingleTile() const
+ inline bool IsSingleTile() const
{
return (this->facilities & FACIL_TRAIN) != 0 && this->train_station.w == 1 && this->train_station.h == 1;
}
@@ -61,7 +61,7 @@ struct Waypoint FINAL : SpecializedStation<Waypoint, true> {
* @param wp The waypoint to compare to.
* @return true iff their types are equal.
*/
- FORCEINLINE bool IsOfType(const Waypoint *wp) const
+ inline bool IsOfType(const Waypoint *wp) const
{
return this->string_id == wp->string_id;
}
@@ -27,7 +27,7 @@ struct Waypoint FINAL : SpecializedStation<Waypoint, true> {
void UpdateVirtCoord();
- /* virtual */ FORCEINLINE bool TileBelongsToRailStation(TileIndex tile) const
+ /* virtual */ inline bool TileBelongsToRailStation(TileIndex tile) const
{
return IsRailWaypointTile(tile) && GetStationIndex(tile) == this->index;